@@ -3,7 +3,7 @@ import time
 
 import ccxt
 
-from base import BaseExchange
+from .base import BaseExchange
 
 class Binance(BaseExchange):
     """
